import unittest
from generate_password import generate_password, names

class TestGeneratePassword(unittest.TestCase):

    def test_password_length(self):
        # Test the length of the generated password
        password = generate_password()
        self.assertGreaterEqual(len(password), 6)
        self.assertLessEqual(len(password), 12)

    def test_password_requirements(self):
        # Test if the generated password meets the specified requirements
        password = generate_password()
        self.assertTrue(any(char.isupper() for char in password))
        self.assertTrue(any(char.islower() for char in password))
        self.assertTrue(any(char.isdigit() for char in password))
        self.assertNotIn(password.lower(), names)

if __name__ == '__main__':
    unittest.main()
    
    
#python -m unittest test_generate_password.py




import random
import string
import os

# Get the current working directory
current_working_dir = os.getcwd()

# File names
PLACES_FILE = 'places.csv'
BIRD_FILE = 'bird.csv'

# File paths
#places_file_path = os.path.join(current_working_dir, PLACES_FILE)
#bird_file_path = os.path.join(current_working_dir, BIRD_FILE)

places_file_path = os.path.join(current_working_dir, "passwgeneration", PLACES_FILE)
bird_file_path = os.path.join(current_working_dir, "passwgeneration", BIRD_FILE)


# Read names from the files
with open(places_file_path, 'r', encoding='utf-8') as file1, open(bird_file_path, 'r', encoding='utf-8') as file2:
    names1 = set(name.strip().lower() for name in file1)
    names2 = set(name.strip().lower() for name in file2)
    names = names1.union(names2)

# Define function to generate random password
def generate_password():
    """
    Generate a random password that meets the specified requirement.

    Returns:
        str: A randomly generated password.
    """
    while True:
        # Generate random password with length between 6 and 12 characters
        password = ''.join(random.choices(string.ascii_letters + string.digits, k=random.randint(6, 12)))

        # Check if password meets requirements and is not in the names set
        if any(char.isupper() for char in password) and any(char.islower() for char in password) and any(char.isdigit() for char in password) and password.lower() not in names:
            return password

# Call function to generate password and then print
RANDOM_PASSWORD = generate_password()

# Print the generated password
print(RANDOM_PASSWORD)




from setuptools import setup, find_packages

setup(
    name='passwgeneration',       # Replace with the name of your package
    version='1.1.8',                # Replace with the version number of your package
    author='kanchan',             # Replace with the author's name
    author_email='kanchanbora321@gmail.com',  # Replace with the author's email
    description='Python package to generate random passwords of maximum length 12, avoiding names present in specified files.',
    long_description='generate password',  # Use README.md content or plain text
    long_description_content_type='text/plain',  # Specify the type of long description (text/plain, text/markdown, etc.)
    url='https://github.com/kanchann23/genUniquePassw',  # Replace with the URL of your package's repository
    license='MIT',                  # Replace with the license type of your package
    keywords=['security', 'password'],  # Replace with relevant keywords related to your package
    packages=find_packages(),       # Automatically find and include all packages in the project
   
    classifiers=[                   # List of classifiers to categorize your package on PyPI
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)

